#
# spec file for package waypipe
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           waypipe
Version:        0.9.1
Release:        1.5
Summary:        Proxy for Wayland clients
License:        MIT
Group:          System/X11/Servers
URL:            https://mstoeckl.com/notes/gsoc/blog.html
Source:         https://gitlab.freedesktop.org/mstoeckl/waypipe/-/archive/v%{version}/%{name}-v%{version}.tar.gz#/%{name}-%{version}.tar.xz
BuildRequires:  meson >= 0.47
BuildRequires:  pkgconfig(gbm)
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavutil)
BuildRequires:  pkgconfig(libdrm)
BuildRequires:  pkgconfig(liblz4) >= 1.7.0
BuildRequires:  pkgconfig(libswscale)
BuildRequires:  pkgconfig(libva)
BuildRequires:  pkgconfig(libzstd) >= 0.4.6
BuildRequires:  pkgconfig(scdoc) >= 1.9.4
BuildRequires:  pkgconfig(wayland-client)
BuildRequires:  pkgconfig(wayland-protocols)
BuildRequires:  pkgconfig(wayland-server)

%description
waypipe is a proxy for Wayland clients. It forwards Wayland messages
and serializes changes to shared memory buffers over a single socket.
This makes application forwarding similar to `ssh -X` feasible.

Waypipe needs to be run on both ends of a socket connection. It
emulates shared files between the different systems on each end of
the connection, using twin file copies to quickly identify file
changes.

It supports both shared-memory and DMABUFs. Performance on a local
network is kind of acceptable for terminals and relatively static
applications, but games are often unplayable due to FPS drop from the
delay needed to send a screenful of data over the network.

%prep
%autosetup -p1 -n waypipe-v%version

%build
%meson
%meson_build

%install
%meson_install

%files
%_bindir/waypipe
%_mandir/man*/waypipe*
%license COPYING
%doc README*

%changelog
* Thu Jun 13 2024 Joshua Smith <smolsheep@opensuse.org>
- Update to version 0.9.1:
  * Filtering out the linux-drm-syncobj-v1 protocol, which uses a
    file descriptor type for Waypipe currently does not support.
  * Not aborting/producing a core dump on receipt of a second
    SIGINT (Ctrl+C) signal: this was too easy to trigger
    accidentally. SIGQUIT (Ctrl+\) already exists for this purpose
* Mon Mar 18 2024 Dirk Müller <dmueller@suse.com>
- update to 0.9.0:
  * enables LZ4 compression by default. This may lead to "Lz4
    decompression failed" errors when connecting a pre-v0.8.2
    waypipe server instance to a v0.9.0 waypipe client. Explicitly
    passing the --compress lz4 flag to waypipe ssh should fix this,
    by ensuring that both ends of the connection try the same
    compression type.
  * --title-prefix flag, which lets Waypipe prepend strings to
    window titles
  * adds the --vsock flag, to permit connections through AF_VSOCK
  * adds support for AV1 video encoding/decoding via --video=av1
* Sat Jul  1 2023 Boris Manojlovic <boris@steki.net>
- Update to version 0.8.6
  * Handle pipe poll errors by closing pipe
  * Update core Wayland protocol file and shm formats
  * Update core Wayland protocol file and shm formats
  * Fix a memory leak
  * Move acknowledgement logic to separate function
  * Log when metadata messages received
  * Avoid duplicate video encode setup
  * Fix a crash with ffmpeg 6.0
  * Allow --drm-node option in ssh and client modes
  * Provide dmabuf main device from opened drm fd
  * Avoid acquiring controlling terminal
  * Update issue filing guidelines
  * Fix dmabuf-feedback event ordering
  * Allow concurrent read/write of dmabuf
  * Deduplicate dmabuf format restriction logic
  * Remove dmabuf fd deduplication logic
  * Adjust dmabuf stride when using wl_drm
  * Fix dmabuf write bug with amdgpu
  * Remove unused argument from map_dmabuf
  * Fix negative-sized memcpy bug
  * Add missing casts
  * Use local stride when computing diffs
  * Fix strict prototype warnings
  * Split initial mirror synchronization over threads
  * Use local stride when applying diffs
  * Remove modifier gate for video encoding
  * Optinally permit tiled formats with dmabuf v4
  * Fix a stride mismatch bug with video encoding
  * Serialize dmabuf plane info instead of copying
  * Remove unnecessary delay
  * Fix typo/missing negation
  * Clarify unidentified protocol message
  * Minor fd_mirror test adjustments
  * Remove unused argument
  * Fix use-after-free in zeroed_aligned_realloc
  * Delay switch to default LZ4 compression again
  * Use O_PATH to open directories on Linux
  * Fix compile error when dmabufs disabled
  * Remove unused path from make_dmabuf
  * Fix use of uninitialized memory
  * Use longer paths in startup failure test
  * Fix handling of relative socket paths
  * Use posix_spawn to start server command
  * Zero initialize cmsg data
  * Rewrite socket connect/bind/unlink handling
  * Downgrade fd leak warnings to debug
  * Fix type conversion warnings
  * Remove outdated dmabuf import paths
  * Remove code to autodetect DMABUFs
  * Only allow single-plane DMABUF formats
  * Mention AcceptEnv/SetEnv method of setting env variables
  * Hide build-minimal/ generated folder in gitignore
  * Mention default socket prefix in man page
  * Explain how to set env variables for waypipe server
  * Demote application close warning to debug
  * Stop setting h264 hw encode quality
  * Add basic support for dmabuf-feedback
  * Generate protocol interface versions
  * Remove restriction on video thread count
  * Autoformat change
  * Improve timeout handling in startup test
  * Make expected behavior more explicit for startup test
  * Return 0 on 'waypipe --help'
  * Switch to using LZ4 compression by default
* Sat Feb 12 2022 Arnav Singh <opensuse@arnavion.dev>
- Update to version 0.8.2
  * Print useful error messages when connecting waypipe instances
    with incompatible command line options.
- Update to version 0.8.1
  * Improved performance by reducing executable size, and memory
    usage on networks with high bandwidth and latency.
  * Fixed an issue running OpenGL programs with the compositor
    Mutter in some cases.
  * Fixed a bug in which Waypipe failed to read certain readonly
    file descriptors.
- Update to version 0.8.0
  * Added support for video encoding with VP9.
  * Command line interface changes:
  * `--video` now takes an optional list of arguments specifying
    video encoding properties. For example, the argument list
    `--video=hw,vp9,bpf=5e5` provides hardware video encoding as
    VP9 with a higher bit rate than usual.
  * `--hwvideo` is deprecated in favor of writing `--video=hw`.
  * The short option `-v` has been removed; use the longer form
    `--version` instead.
  * `waypipe ssh` now calls whatever ssh executable is in $PATH,
    instead of `/usr/bin/ssh`
* Sat Feb 20 2021 Florian <sp1ritCS@protonmail.com>
- Update to version 0.7.2
  * Fixed a crash when using DMABUFs with the nouveau driver
  * Eliminated two file descriptor leaks in the main server process
  * Fixed a bug with damage tracking
  * Added support for read-only file descriptors, fixing a bug with
    recent wl_keyboard protocol versions
  * Slightly expanded man page documentation
  * Some setup work to support setting video encoding parameters in
    future versions of Waypipe
- version 0.7.1
  * Fixes a crash with large (e.g, 2500x2000 pixel) windows
  * Fixes a crash with video encoding and some ffmpeg versions (bd702a58)
  * Protocol support has been added for wlr-gamma-control-v1 and
    primary-selection-unstable-v1.
  * Keyboard keymap file descriptors are now cleaned up more
    quickly.
- version 0.7.0
  * Numerous bugfixes
  * This release is not compatible with earlier versions of
    Waypipe, due to changes in the wire protocol (slightly better
    file descriptor tracking, and a new connection method.)
  * There is a new --remote-bin option for the waypipe ssh mode
    which can be used to choose the binary run on the remote
    (application side) system, rather than looking only for
    "waypipe" in $PATH.
* Fri Aug 30 2019 Jan Engelhardt <jengelh@inai.de>
- Initial package (version 0.6.1) for build.opensuse.org
